============
Installation
============

At the command line::

    pip install mrktmix

To use optimization function, one needs to install Numpy+MKL. Please follow installation process on `Install Python 3.6 with Numpy + MKL, SciPy , Matplotlib and Pandas on Windows
<http://sima02.blogspot.com/2017/09/install-python-36-with-matplotlib-numpy.html>`_.
Download and install `Numpy+MKL
<https://www.lfd.uci.edu/~gohlke/pythonlibs/#numpy>`_. Ater installing Numpy+MKL, install gpkit::

	pip install gpkit
